.. application.archiving.archive_spec.rst
..
.. Project: AutoArchive
.. License: GNU GPLv3
..
.. Copyright (C) 2003 - 2017 Róbert Čerňanský



.. A section for the AutoArchive._application.archiving.archive_spec package.



AutoArchive._application.archiving.archive_spec
===============================================

.. automodule:: AutoArchive._application.archiving.archive_spec
   :no-members:



Modules
-------

archive_spec
^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving.archive_spec.archive_spec



archive_spec_options
^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving.archive_spec.archive_spec_options



config_constants
^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving.archive_spec.config_constants



_archive_spec_config_parser
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: AutoArchive._application.archiving.archive_spec._archive_spec_config_parser
.. autoclass:: _ArchiveSpecConfigParser



_sections
^^^^^^^^^

.. automodule:: AutoArchive._application.archiving.archive_spec._sections
.. autoclass:: _Sections
